@@ -1,10 +1,10 @@
 package Crypt::Random::Source::Base;
-BEGIN {
-  $Crypt::Random::Source::Base::AUTHORITY = 'cpan:NUFFIN';
-}
 # ABSTRACT: Abstract base class for L<Crypt::Random::Source> classes
-$Crypt::Random::Source::Base::VERSION = '0.08';
-use Any::Moose;
+
+our $VERSION = '0.11';
+
+use Moo;
+use namespace::clean;
 
 sub available { 0 }
 
@@ -54,7 +54,7 @@ Crypt::Random::Source::Base - Abstract base class for L<Crypt::Random::Source> c
 
 =head1 VERSION
 
-version 0.08
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -107,11 +107,16 @@ sources be tried before known bad (slower, less available) sources.
 
 Provided for compatibility with L<Crypt::Random>
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Crypt-Random-Source>
+(or L<bug-Crypt-Random-Source@rt.cpan.org|mailto:bug-Crypt-Random-Source@rt.cpan.org>).
+
 =head1 AUTHOR
 
 יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2008 by Yuval Kogman.
 
