@@ -1,17 +1,14 @@
 package Crypt::Random::Source::Factory;
-BEGIN {
-  $Crypt::Random::Source::Factory::AUTHORITY = 'cpan:NUFFIN';
-}
 # ABSTRACT: Load and instantiate sources of random data
-$Crypt::Random::Source::Factory::VERSION = '0.08';
-use Any::Moose;
-use Class::Load 'load_class';
 
+our $VERSION = '0.11';
+
+use Moo;
 use Carp qw(croak);
-
 use Module::Find;
-
-use namespace::clean -except => [qw(meta)];
+use Module::Runtime qw(require_module);
+use Types::Standard qw(ClassName Bool ArrayRef Str);
+use namespace::clean;
 
 sub get {
     my ( $self, %args ) = @_;
@@ -36,10 +33,12 @@ sub get_strong {
 }
 
 has weak_source => (
-    isa => "ClassName",
+    isa => ClassName,
     is  => "rw",
-    lazy_build => 1,
+    lazy => 1,
+    builder => 1,
     clearer    => "clear_weak_source",
+    predicate  => "has_weak_source",
     handles    => { new_weak => "new" },
 );
 
@@ -49,10 +48,12 @@ sub _build_weak_source {
 }
 
 has strong_source => (
-    isa => "ClassName",
+    isa => ClassName,
     is  => "rw",
-    lazy_build => 1,
+    lazy => 1,
+    builder => 1,
     clearer    => "clear_strong_source",
+    predicate  => 'has_strong_source',
     handles    => { new_strong => "new" },
 );
 
@@ -62,10 +63,12 @@ sub _build_strong_source {
 }
 
 has any_source => (
-    isa => "ClassName",
+    isa => ClassName,
     is  => "rw",
-    lazy_build => 1,
+    lazy => 1,
+    builder => 1,
     clearer    => "clear_any_source",
+    predicate  => 'has_any_source',
     handles    => { new_any => 'new' },
 );
 
@@ -76,8 +79,11 @@ sub _build_any_source {
 
 has scan_inc => (
     is  => "ro",
-    isa => "Bool",
-    lazy_build => 1,
+    isa => Bool,
+    lazy => 1,
+    builder => 1,
+    clearer => 'clear_scan_inc',
+    predicate => 'has_scan_inc',
 );
 
 sub _build_scan_inc {
@@ -91,9 +97,12 @@ sub _build_scan_inc {
 }
 
 has weak_sources => (
-    isa => "ArrayRef[Str]",
+    isa => ArrayRef[Str],
     is  => "rw",
-    lazy_build => 1,
+    lazy => 1,
+    builder => 1,
+    clearer => 'clear_weak_sources',
+    predicate => 'has_weak_sources',
 );
 
 sub _build_weak_sources {
@@ -111,9 +120,12 @@ sub _build_weak_sources {
 }
 
 has strong_sources => (
-    isa => "ArrayRef[Str]",
+    isa => ArrayRef[Str],
     is  => "rw",
-    lazy_build => 1,
+    lazy => 1,
+    builder => 1,
+    clearer => 'clear_strong_sources',
+    predicate => 'has_strong_sources',
 );
 
 sub _build_strong_sources {
@@ -132,7 +144,7 @@ sub _build_strong_sources {
 sub best_available {
     my ( $self, @sources ) = @_;
 
-    my @available = grep { local $@; eval { Class::Load::load_class($_); $_->available }; } @sources;
+    my @available = grep { local $@; eval { require_module($_); $_->available }; } @sources;
 
     my @sorted = sort { $b->rank <=> $a->rank } @available;
 
@@ -144,7 +156,7 @@ sub first_available {
 
     foreach my $class ( @sources ) {
         local $@;
-        return $class if eval { Class::Load::load_class($class); $class->available };
+        return $class if eval { require_module($class); $class->available };
     }
 }
 
@@ -169,7 +181,7 @@ Crypt::Random::Source::Factory - Load and instantiate sources of random data
 
 =head1 VERSION
 
-version 0.08
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -206,11 +218,16 @@ The C<type> argument can be C<weak>, C<strong> or C<any>.
 
 Instantiate a new weak or strong random source.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Crypt-Random-Source>
+(or L<bug-Crypt-Random-Source@rt.cpan.org|mailto:bug-Crypt-Random-Source@rt.cpan.org>).
+
 =head1 AUTHOR
 
 יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2008 by Yuval Kogman.
 
