@@ -1,10 +1,10 @@
 package Crypt::Random::Source::Strong;
-BEGIN {
-  $Crypt::Random::Source::Strong::AUTHORITY = 'cpan:NUFFIN';
-}
 # ABSTRACT: Abstract base class for strong random data sources
-$Crypt::Random::Source::Strong::VERSION = '0.08';
-use Any::Moose;
+
+our $VERSION = '0.11';
+
+use Moo;
+use namespace::clean;
 
 sub is_strong { 1 }
 
@@ -20,7 +20,7 @@ Crypt::Random::Source::Strong - Abstract base class for strong random data sourc
 
 =head1 VERSION
 
-version 0.08
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -38,11 +38,16 @@ This is an abstract base class. There isn't much to describe.
 
 Returns true
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Crypt-Random-Source>
+(or L<bug-Crypt-Random-Source@rt.cpan.org|mailto:bug-Crypt-Random-Source@rt.cpan.org>).
+
 =head1 AUTHOR
 
 יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2008 by Yuval Kogman.
 
