@@ -1,16 +1,16 @@
 package Crypt::Random::Source::Strong::devrandom;
-BEGIN {
-  $Crypt::Random::Source::Strong::devrandom::AUTHORITY = 'cpan:NUFFIN';
-}
 # ABSTRACT: A strong random data source using F</dev/random>
-$Crypt::Random::Source::Strong::devrandom::VERSION = '0.08';
-use Any::Moose;
+
+our $VERSION = '0.11';
+
+use Moo;
 
 extends qw(
     Crypt::Random::Source::Strong
     Crypt::Random::Source::Base::RandomDevice
 );
 
+use namespace::clean;
 
 sub default_path { "/dev/random" }
 
@@ -26,17 +26,22 @@ Crypt::Random::Source::Strong::devrandom - A strong random data source using F</
 
 =head1 VERSION
 
-version 0.08
+version 0.11
 
 =head1 SYNOPSIS
 
     use Crypt::Random::Source::Strong::devrandom;
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Crypt-Random-Source>
+(or L<bug-Crypt-Random-Source@rt.cpan.org|mailto:bug-Crypt-Random-Source@rt.cpan.org>).
+
 =head1 AUTHOR
 
 יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2008 by Yuval Kogman.
 
