@@ -1,15 +1,15 @@
 package Crypt::Random::Source::Weak::devurandom;
-BEGIN {
-  $Crypt::Random::Source::Weak::devurandom::AUTHORITY = 'cpan:NUFFIN';
-}
 # ABSTRACT: A weak random data source using F</dev/urandom>
-$Crypt::Random::Source::Weak::devurandom::VERSION = '0.08';
-use Any::Moose;
+
+our $VERSION = '0.11';
+
+use Moo;
 
 extends qw(
     Crypt::Random::Source::Weak
     Crypt::Random::Source::Base::RandomDevice
 );
+use namespace::clean;
 
 sub default_path { "/dev/urandom" }
 
@@ -25,17 +25,22 @@ Crypt::Random::Source::Weak::devurandom - A weak random data source using F</dev
 
 =head1 VERSION
 
-version 0.08
+version 0.11
 
 =head1 SYNOPSIS
 
     use Crypt::Random::Source::Weak::devurandom;
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Crypt-Random-Source>
+(or L<bug-Crypt-Random-Source@rt.cpan.org|mailto:bug-Crypt-Random-Source@rt.cpan.org>).
+
 =head1 AUTHOR
 
 יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2008 by Yuval Kogman.
 
